@@ -23,9 +23,9 @@
 #include "lib/result.h"
 #include "lib/animationresult.h"
 
-#include <KFileDialog>
+#include <QFileDialog>
 #include <QDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 AnimationResultItem::AnimationResultItem(QGraphicsObject* parent)
     : WorksheetImageItem(parent), ResultItem(), m_height(0), m_movie(0)
@@ -129,7 +129,7 @@ void AnimationResultItem::updateSize(const QSize& size)
 void AnimationResultItem::saveResult()
 {
     Cantor::Result* res = result();
-    const QString& filename=KFileDialog::getSaveFileName(QUrl(), res->mimeType(), worksheet()->worksheetView());
+    const QString& filename=QFileDialog::getSaveFileName(worksheet()->worksheetView(), i18n("Save result"), QString(), res->mimeType());
     qDebug()<<"saving result to "<<filename;
     res->save(filename);
 }
